# -graphic-image-processing
GIP (Graphic Image Processing) aims to facilitate both Pre-processing and graphic plot of images, using libraries already available in the literature.
     It will provide functions that have summarized multiple lines of code into just one, as well as making it easy for those looking to enter the 
     world of image processing to get started.
   

## GraficPlot
 This module aims to simplify the plot of graphics in order to make it more 
intuitive and practical, plotting several images in user-defined axis, 
as well as plotting their histogram. It will also display several graphs 
of the same image and finally create line graphs of the learning metrics
### Multiple image plot examples
![Screenshot](imagem/plot.png)

### Multiple-image histogram plot examples
![Screenshot](imagem/histograma.png)
 
 
 ### Examples of the metrics chart
![Screenshot](imagem/metricas.png)
 
 
 ### Example of multiple plots of the same image
![Screenshot](imagem/multi.png)
 
 
## ImageFilters
ImageFilters comes to facilitate the application of filters in an entire 
image dataset, being able to apply a filter to a certain color channel, 
also performing the division of an image base in test, train and validation, 
saving the images in folders so make life easier for the user.

 ### Examples of Applying Multiple Filters to an Image
![Screenshot](imagem/equaliza.png)

 ### Examples of applying a filter to a color channel
![Screenshot](imagem/canal.png)

## CreateBox


This module offers the possibility of creating masks and plotting bounding 
boxes on this mask, passed through an xml and csv file, being also able to 
plot the boxes in an image.
### Examples of bounding boxes in an image
![Screenshot](imagem/boxe_tuberculosis-phone-0088.jpg)
### Examples of bouding boxes in a mask
![Screenshot](imagem/maskboxe_tuberculosis-phone-0088.jpg)

